# History

## 0.0.16 (2022-01-30)

* Add tests back to distribution.

## 0.0.15 (2022-01-30)

* Use miniver instead of versioneer.

## 0.0.10 (2021-12-30)

* Add versioneer.py to the source distribution.

## 0.0.9 (2021-11-17)

* Retrigger failed build due to travis.org migration.

## 0.0.8 (2021-06-16)

* Add support for pre-release packages that don't use a dot to separate the pre-release signifier.

## 0.0.7 (2021-11-03)

* Show default argument values in the help.

## 0.0.6 (2021-11-03)

* Support a few more time formats

## 0.0.5 (2020-10-13)

* Use pretty table for better formatting.

## 0.0.4 (2020-10-12)

* Improve documentation.

## 0.0.1 (2020-03-11)

* First release on PyPI.
